spannertools.GlissandoSpanner
=============================

.. abjad-lineage:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner

.. autoclass:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.append
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.append_left
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.attach
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.components
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.detach
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.extend
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.extend_left
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.fracture
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.fuse
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.get_duration
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.get_timespan
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.index
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.leaves
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.override
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.pop
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.pop_left
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.set
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.__call__
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.__contains__
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.__copy__
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.__eq__
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.__getitem__
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.__len__
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.__lt__
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.__ne__
      ~abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.__repr__

Bases
-----

- :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner.Spanner>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.leaves
   :noindex:

.. autoattribute:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.override
   :noindex:

.. autoattribute:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.set
   :noindex:

Methods
-------

.. automethod:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.append
   :noindex:

.. automethod:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.append_left
   :noindex:

.. automethod:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.attach
   :noindex:

.. automethod:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.detach
   :noindex:

.. automethod:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.extend
   :noindex:

.. automethod:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.extend_left
   :noindex:

.. automethod:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.fracture
   :noindex:

.. automethod:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.fuse
   :noindex:

.. automethod:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.get_duration
   :noindex:

.. automethod:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.get_timespan
   :noindex:

.. automethod:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.index
   :noindex:

.. automethod:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.pop
   :noindex:

.. automethod:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.pop_left
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.__call__
   :noindex:

.. automethod:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.__copy__
   :noindex:

.. automethod:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.GlissandoSpanner.GlissandoSpanner.GlissandoSpanner.__repr__
   :noindex:
